@@ -1,9 +1,32 @@
 import struct
+from enum import IntEnum, IntFlag
 
 from spherov2.listeners.async_ import CollisionDetected
 from spherov2.listeners.core import PowerStates
 
 
+class CollisionAxis(IntFlag):
+    X_AXIS = 0x1  # 0b1
+    Y_AXIS = 0x2  # 0b10
+
+
+class GyroMaxExceedsFlags(IntFlag):
+    X_POSITIVE = 0x1  # 0b1
+    X_NEGATIVE = 0x2  # 0b10
+    Y_POSITIVE = 0x4  # 0b100
+    Y_NEGATIVE = 0x8  # 0b1000
+    Z_POSITIVE = 0x10  # 0b10000
+    Z_NEGATIVE = 0x20  # 0b100000
+
+
+class PowerStates(IntEnum):
+    UNKNOWN = 0
+    CHARGING = 1
+    OK = 2
+    LOW = 3
+    CRITICAL = 4
+
+
 class Async:
     battery_state_changed_notify = (0xfe, 1), lambda listener, p: listener(PowerStates(p.data[0]))
     sensor_streaming_data_notify = (
