@@ -10,15 +10,14 @@ from spherov2.commands.io import IO
 from spherov2.commands.power import Power
 from spherov2.commands.sensor import Sensor
 from spherov2.commands.system_info import SystemInfo
-from spherov2.controls.v2 import AnimationControl, DriveControl, LedControl, SensorControl, StatsControl, \
-    Processors
+from spherov2.controls.v2 import AnimationControl, DriveControl, LedControl, SensorControl, StatsControl, Processors
 from spherov2.toy import ToyV2, Toy, ToySensor
 from spherov2.types import ToyType
 
 
 class BOLT(ToyV2):
     toy_type = ToyType('Sphero BOLT', 'SB-', 'SB', .075)
-    _handshake = [('00020005-574f-4f20-5370-6865726f2121', bytearray(b'usetheforce...band'))]
+    _handshake = [('00020005-574f-4f20-5370-6865726f2121', bytearray(b'usetheforce...band'))] #TODO: find correct info here
 
     class LEDs(IntEnum):
         FRONT_RED = 0
@@ -64,7 +63,9 @@ class BOLT(ToyV2):
             x=ToySensor(0x2000000, -20000., 20000.),
             y=ToySensor(0x1000000, -20000., 20000.),
             z=ToySensor(0x800000, -20000., 20000.)
-        )
+        ),
+        ambient_light=OrderedDict(
+            ambient_light=ToySensor(0x40000, 120000., 120000.))
     )
 
     # Bolt Supported calls
@@ -84,12 +85,17 @@ class BOLT(ToyV2):
     get_bluetooth_name = Connection.get_bluetooth_name  # GetBluetoothNameCommand
     set_bluetooth_name = Connection.set_bluetooth_name  # SetBluetoothNameCommand
 
-    # Drive
-    drive_with_heading = Drive.drive_with_heading  # DriveWithHeadingCommand
-    reset_yaw = Drive.reset_yaw  # ResetYawCommand
-    set_pitch_torque_modification_value = Drive.set_pitch_torque_modification_value  # SetPitchTorqueModificationValueCommand
-    set_raw_motors = Drive.set_raw_motors  # SetRawMotorsCommand
-    set_stabilization = Drive.set_stabilization  # SetStabilizationCommand
+    #Drive - Driving done on the Secondary Processor
+    drive_with_heading = partialmethod(Drive.drive_with_heading,
+                                                      proc=Processors.SECONDARY) #DriveWithHeadingCommand
+    reset_yaw = partialmethod(Drive.reset_yaw,
+                                                      proc=Processors.SECONDARY) #ResetYawCommand
+    set_pitch_torque_modification_value = partialmethod(Drive.set_pitch_torque_modification_value,
+                                                      proc=Processors.SECONDARY) #SetPitchTorqueModificationValueCommand
+    set_raw_motors = partialmethod(Drive.set_raw_motors,
+                                                      proc=Processors.SECONDARY) #SetRawMotorsCommand
+    set_stabilization = partialmethod(Drive.set_stabilization,
+                                                      proc=Processors.SECONDARY) #SetStabilizationCommand
 
     # Firmware
     get_pending_update_flags = Firmware.get_pending_update_flags  # GetPendingUpdateFlagsCommand
@@ -189,11 +195,13 @@ class BOLT(ToyV2):
     remove_collision_detected_notify_listener = partialmethod(Toy._remove_listener,
                                                               Sensor.collision_detected_notify)  # CollisionDetectedNotifyCommand
     configure_collision_detection = Sensor.configure_collision_detection  # ConfigureCollisionDetectionCommand
-    enable_gyro_max_notify = Sensor.enable_gyro_max_notify  # EnableGyroMaxNotifyCommand
-    get_ambient_light_sensor_value = Sensor.get_ambient_light_sensor_value  # GetAmbientLightSensorValueCommand
+    enable_gyro_max_notify = partialmethod(Sensor.enable_gyro_max_notify, proc=Processors.SECONDARY)  # EnableGyroMaxNotifyCommand
+    get_ambient_light_sensor_value = partialmethod(Sensor.get_ambient_light_sensor_value, proc=Processors.SECONDARY)
     get_bot_to_bot_infrared_readings = Sensor.get_bot_to_bot_infrared_readings  # GetBotToBotInfraredReadingsCommand
-    get_extended_sensor_streaming_mask = Sensor.get_extended_sensor_streaming_mask  # GetExtendedSensorStreamingMaskCommand
-    set_sensor_streaming_mask = Sensor.set_sensor_streaming_mask  # GetSensorStreamingMaskCommand
+    get_sensor_streaming_mask = partialmethod(Sensor.get_sensor_streaming_mask, proc=Processors.SECONDARY)  # GetSensorStreamingMaskCommand
+    set_sensor_streaming_mask = partialmethod(Sensor.set_sensor_streaming_mask, proc=Processors.SECONDARY)  # SetSensorStreamingMaskCommand
+    get_extended_sensor_streaming_mask = partialmethod(Sensor.get_extended_sensor_streaming_mask, proc=Processors.SECONDARY)  # GetExtendedSensorStreamingMaskCommand
+    set_extended_sensor_streaming_mask = partialmethod(Sensor.set_extended_sensor_streaming_mask, proc=Processors.SECONDARY)  # SetExtendedSensorStreamingMaskCommand
     add_gyro_max_notify_listener = partialmethod(Toy._add_listener, Sensor.gyro_max_notify)  # GyroMaxNotifyCommand
     remove_gyro_max_notify_listener = partialmethod(Toy._remove_listener,
                                                     Sensor.gyro_max_notify)  # GyroMaxNotifyCommand
@@ -203,7 +211,7 @@ class BOLT(ToyV2):
                                                                Sensor.magnetometer_north_yaw_notify)  # MagnetometerNorthYawNotifyCommand
     remove_magnetometer_north_yaw_notify_listener = partialmethod(Toy._remove_listener,
                                                                   Sensor.magnetometer_north_yaw_notify)  # MagnetometerNorthYawNotifyCommand
-    reset_locator_x_and_y = Sensor.reset_locator_x_and_y  # ResetLocationXAndYCommand
+    reset_locator_x_and_y = partialmethod(Sensor.reset_locator_x_and_y, proc=Processors.SECONDARY)  # ResetLocationXAndYCommand
     add_robot_to_robot_infrared_message_received_notify_listener = partialmethod(Toy._add_listener,
                                                                                  Sensor.robot_to_robot_infrared_message_received_notify)  ##RobotToRobotInfraredMessageReceivedNotifyCommand
     remove_robot_to_robot_infrared_message_received_notify_listener = partialmethod(Toy._remove_listener,
@@ -213,9 +221,7 @@ class BOLT(ToyV2):
                                                               Sensor.sensor_streaming_data_notify)  # SensorStreamingDataNotifyCommand
     remove_sensor_streaming_data_notify_listener = partialmethod(Toy._remove_listener,
                                                                  Sensor.sensor_streaming_data_notify)  # SensorStreamingDataNotifyCommand
-    set_extended_sensor_streaming_mask = Sensor.set_extended_sensor_streaming_mask  # SetExtendedSensorStreamingMaskCommand
     set_locator_flags = Sensor.set_locator_flags  # SetLocatorFlagsCommand
-    get_sensor_streaming_mask = Sensor.get_sensor_streaming_mask  # SetSensorStreamingMaskCommand
     start_robot_to_robot_infrared_broadcasting = Sensor.start_robot_to_robot_infrared_broadcasting  # StartRobotToRobotInfraredBroadcastingCommand
     start_robot_to_robot_infrared_evading = Sensor.start_robot_to_robot_infrared_evading  # StartRobotToRobotInfraredEvadingCommand
     start_robot_to_robot_infrared_following = Sensor.start_robot_to_robot_infrared_following  # StartRobotToRobotInfraredFollowingCommand
@@ -259,9 +265,10 @@ class BOLT(ToyV2):
         return LedControl(self)
 
     @property
-    @lru_cache(None)
     def sensor_control(self):
-        return SensorControl(self)
+        if self._sensor_controller is None: #Make a new SensorControl if necessary (NOT A UTIL CLASS)
+            self._sensor_controller = SensorControl(self)
+        return self._sensor_controller
 
     @property
     @lru_cache(None)
